package cn.iocoder.yudao.module.customer.vo.customer.vo;

import cn.iocoder.yudao.module.customer.vo.customer.customerContacts.CustomerContactsCreateReqVO;
import cn.iocoder.yudao.module.customer.vo.customer.line.CustomerLineCreateReqVO;
import cn.iocoder.yudao.module.customer.vo.customerBank.CustomerBankCreateReqVO;
import com.fasterxml.jackson.annotation.JsonIgnore;
import io.swagger.annotations.ApiModel;
import io.swagger.annotations.ApiModelProperty;
import lombok.Data;
import lombok.EqualsAndHashCode;
import lombok.ToString;

import javax.validation.Valid;
import java.math.BigDecimal;
import java.util.Date;
import java.util.List;


@ApiModel("管理后台 - 客户创建 Request VO")
@Data
@EqualsAndHashCode(callSuper = true)
@ToString(callSuper = true)
public class CustomerCreateReqVO extends CustomerBaseVO {

    @ApiModelProperty(value = "客户类型", notes = "参见customer_type数据字典")
    private String type;

    @ApiModelProperty(value = "客户货运类型", notes = "参见customer_transport_type数据字典")
    private String transportType;

    @ApiModelProperty(value = "客户资源类型", notes = "参见customer_resource_type数据字典")
    private Integer resourceType;

    @ApiModelProperty(value = "所属代理")
    private Long agentId;

    @ApiModelProperty(value = "公司名称")
    private String company;

    @ApiModelProperty(value = "公司英文名称")
    private String companyEn;

    @ApiModelProperty(value = "联系地址")
    private String address;

    @ApiModelProperty(value = "产品类型id")
    private Long productType;

    @ApiModelProperty(value = "产品id")
    private Long productId;

    @ApiModelProperty(value = "常用提货网点id")
    private Long pickupPoint;

    @ApiModelProperty(value = "关联会员账号id")
    private Long memberId;

    @ApiModelProperty(value = "客户生日", example = "1652017501000")
    private Date birthday;


    @ApiModelProperty(value = "结算方式", notes = "参见customer_balance数据字典")
    private Integer balance;

    @ApiModelProperty(value = "客户来源", notes = "参见customer_source数据字典")
    private Integer source;

    @ApiModelProperty(value = "图片")
    private String picture;

    @ApiModelProperty(value = "推介人id")
    private Long promoter;

    @ApiModelProperty(value = "创建人id")
    private Long founder;

    @ApiModelProperty(value = "创建时间", example = "1652017501000")
    private Date createTime;


    //--------发票信息
    @ApiModelProperty(value = "发票抬头")
    private String invoiceTitle;

    @ApiModelProperty(value = "纳税人识别号")
    private String licenseNumber;

    @ApiModelProperty(value = "开户行")
    private String bank;

    @ApiModelProperty(value = "账户")
    private String bankNumber;

    @ApiModelProperty(value = "项目")
    private String project;

    @ApiModelProperty(value = "开票地址")
    private String billingAddress;

    @ApiModelProperty(value = "开票电话")
    private String billingTell;

    @ApiModelProperty(value = "税率")
    private BigDecimal taxRate;

    @ApiModelProperty(value = "备注")
    private String remarks;


    @ApiModelProperty(value = "到仓确认", notes = "参见枚举 CommonStatusEnum")
    private Integer arrivalConfirm;

    @ApiModelProperty(value = "重货标准(CBM)")
    private BigDecimal weightUnit;

    @ApiModelProperty(value = "泡货标准(CBM)")
    private BigDecimal lightUnit;


    @ApiModelProperty(value = "询价详情")
    private String enquiryInfo;


    /**
     * 是否显示提单价格
     */
    @ApiModelProperty(value = "是否显示提单价格")
    private Boolean isShowTidanPrice;



    @ApiModelProperty(value = "客户是否确认, 待分配页面新增时需要设置true， 其他情况可以不传")
    private Boolean isCustomerServiceConfirmed = false;

    /**
     * 联系人
     */
    @ApiModelProperty(value = "联系人列表", notes = "参见CustomerContactsCreateReqVO")
    @Valid
    private List<CustomerContactsCreateReqVO> customerContacts;


    /**
     * 客户线路集合
     */
    @ApiModelProperty(value = "客户线路集合", notes = "参见CustomerLineCreateReqVO")
    @Valid
    private List<CustomerLineCreateReqVO> customerLines;

    /**
     * 客户银行账号
     */
    @ApiModelProperty(value = "客户银行账户", notes = "参见CustomerBankCreateReqVO")
    private List<CustomerBankCreateReqVO> customerBanks;



    /**
     * 是否系统创建 0为手动 1为注册时系统创建 2为下单时系统创建
     */
    @JsonIgnore
    private Integer isAuto;
    /**
     * 创建客户操作日志的remark。内部方法传递时使用。
     */
    @JsonIgnore
    private String customerOperateLogRemark;

    /**
     * 创建客户操作日志的OrderNo。内部方法传递时使用。
     */
    @JsonIgnore
    private String customerOperateLogOrderNo;



    /**
     * 是否被订单收货人同步的
     */
    private Boolean isWebOrderConsigneeSync = false;


    /**
     * 询盘信息
     */
    private String inquiry;


    /**
     * 是否潜在客户
     */
    private Boolean isPotential = false;


}
