package cn.iocoder.yudao.module.customer.vo.customer.vo;

import cn.iocoder.yudao.module.customer.vo.customerBank.CustomerBankBackVO;
import com.fasterxml.jackson.annotation.JsonFormat;
import io.swagger.annotations.ApiModel;
import io.swagger.annotations.ApiModelProperty;
import lombok.Data;
import lombok.EqualsAndHashCode;
import lombok.ToString;
import org.springframework.format.annotation.DateTimeFormat;

import java.math.BigDecimal;
import java.util.Date;
import java.util.List;

import static cn.iocoder.yudao.framework.common.util.date.DateUtils.*;

@ApiModel("管理后台 - 客户详情 Response VO")
@Data
@EqualsAndHashCode(callSuper = true)
@ToString(callSuper = true)
public class CustomerDetailRespVO extends CustomerBaseVO {

    @ApiModelProperty(value = "主键")
    private Long id;

    @ApiModelProperty(value = "客户类型", notes = "参见customer_type数据字典")
    private String type;

    @ApiModelProperty(value = "客户货运类型", notes = "参见customer_transport_type数据字典")
    private String transportType;

    @ApiModelProperty(value = "客户资源类型", notes = "参见customer_resource_type数据字典")
    private Integer resourceType;

    @ApiModelProperty(value = "是否在公海")
    private Boolean isInOpenSea;

    @DateTimeFormat(pattern = FORMAT_YEAR_MONTH_DAY_HOUR_MINUTE_SECOND)
    @ApiModelProperty(value = "进入公海时间")
    private Date enterOpenSeaTime;

    @DateTimeFormat(pattern = FORMAT_YEAR_MONTH_DAY_HOUR_MINUTE_SECOND)
    @ApiModelProperty(value = "预计进入公海时间")
    private Date estimateEnterOpenSeaTime;

    @DateTimeFormat(pattern = FORMAT_YEAR_MONTH_DAY_HOUR_MINUTE_SECOND)
    @ApiModelProperty(value = "公海池捞取时间")
    private Date catchTime;

    @ApiModelProperty(value = "所属代理")
    private Long agentId;

    @ApiModelProperty(value = "公司名称")
    private String company;

    @ApiModelProperty(value = "公司英文名称")
    private String companyEn;

    @ApiModelProperty(value = "联系地址")
    private String address;

    @ApiModelProperty(value = "产品类型id")
    private Long productType;

    @ApiModelProperty(value = "产品id")
    private Long productId;

    @ApiModelProperty(value = "常用提货网点id")
    private Long pickupPoint;

    @ApiModelProperty(value = "关联会员账号id")
    private Long memberId;

    @ApiModelProperty(value = "客户生日", example = "1652017501000")
    private Date birthday;


    @ApiModelProperty(value = "结算方式", notes = "参见customer_balance数据字典")
    private Integer balance;

    @ApiModelProperty(value = "客户来源", notes = "参见customer_source数据字典")
    private Integer source;

    @ApiModelProperty(value = "图片")
    private String picture;

    @ApiModelProperty(value = "推介人id")
    private Long promoter;

    @ApiModelProperty(value = "推介人名称")
    private String promoterName;

    @ApiModelProperty(value = "创建人id")
    private Long founder;

    //客户创建日期格式化
    //@JsonFormat(value = "创建时间", example = "1652017501000")
    @JsonFormat(pattern = FORMAT_YEAR_MONTH_DAY,
            timezone = TIME_ZONE_DEFAULT)
    private Date createTime;


    //--------发票信息
    @ApiModelProperty(value = "发票抬头")
    private String invoiceTitle;

    @ApiModelProperty(value = "纳税人识别号")
    private String licenseNumber;

    @ApiModelProperty(value = "开户行")
    private String bank;

    @ApiModelProperty(value = "账户")
    private String bankNumber;

    @ApiModelProperty(value = "项目")
    private String project;

    @ApiModelProperty(value = "开票地址")
    private String billingAddress;

    @ApiModelProperty(value = "开票电话")
    private String billingTell;

    @ApiModelProperty(value = "税率")
    private BigDecimal taxRate;

    @ApiModelProperty(value = "备注")
    private String remarks;


    @ApiModelProperty(value = "到仓确认", notes = "参见枚举 CommonStatusEnum")
    private Integer arrivalConfirm;

    @ApiModelProperty(value = "重货标准(CBM)")
    private BigDecimal weightUnit;

    @ApiModelProperty(value = "泡货标准(CBM)")
    private BigDecimal lightUnit;


    @ApiModelProperty(value = "询价详情")
    private String enquiryInfo;


    /**
     * 是否显示提单价格
     */
    @ApiModelProperty(value = "是否显示提单价格")
    private Boolean isShowTidanPrice;



    @ApiModelProperty(value = "客户是否确认", notes = "待分配页面新增时需要设置true， 其他情况可以不传")
    private Boolean isCustomerServiceConfirmed = false;


    @ApiModelProperty(value = "是否被订单收货人同步的")
    private Boolean isWebOrderConsigneeSync;


    /**
     * 询盘信息
     */
    @ApiModelProperty(value = "询盘信息")
    private String inquiry;


    /**
     * 是否潜在客户
     */
    @ApiModelProperty(value = "是否潜在客户")
    private Boolean isPotential = false;



    @ApiModelProperty(value = "创建人姓名")
    private String founderName;

    @ApiModelProperty(value = "客户银行账号")
    private List<CustomerBankBackVO> customerBankBackVOList;



    @ApiModelProperty(value = "国家中文名称")
    private String countryNameZh;
    @ApiModelProperty(value = "国家英文名称")
    private String countryNameEn;

    @ApiModelProperty(value = "主营类别中文名称")
    private String productTypeNameZh;
    @ApiModelProperty(value = "主营类别英文名称")
    private String productTypeNameEn;

    @ApiModelProperty(value = "主营产品中文名称")
    private String productNameZh;
    @ApiModelProperty(value = "主营产品英文名称")
    private String productNameEn;


    @ApiModelProperty(value = "常用提货点中文名称")
    private String pickupPointNameZh;
    @ApiModelProperty(value = "常用提货点英文名称")
    private String pickupPointNameEn;

    @ApiModelProperty(value = "付款人姓名")
    private String payerName;

    //联系人信息
    private  String contactstr;

}
